@@ -25,22 +25,21 @@
 
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-#pod =for :this This is C<Dist::Zilla::Plugin::Hook> module documentation. Read this if you are going to hack
-#pod or extend C<Dist-Zilla-Plugin-Hook>.
+#pod =for :this This is C<Dist::Zilla::Plugin::Hook> module documentation. Read this if you are going to hack or
+#pod extend C<Dist-Zilla-Plugin-Hook>.
 #pod
-#pod =for :that If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>.
-#pod General topics like getting source, building, installing, bug reporting and some others are covered
-#pod in the L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
+#pod =for :that If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
+#pod topics like getting source, building, installing, bug reporting and some others are covered in the
+#pod L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
 #pod
 #pod =head1 DESCRIPTION
 #pod
 #pod This plugin consumes C<Hooker> role like all other C<Hook> plugins. However, this plugin I<never>
-#pod executes its Perl code. Instead, it just stores it for later use by other plugins.
-#pod
-#pod For example, F<dist.ini> section
+#pod executes its Perl code. Instead, it just stores it for later use by other plugins. As of today,
+#pod only C<Hook> plugin with C<prologue> name is actually used:
 #pod
 #pod     [Hook/prologue]
-#pod         . = use autodiue ':all';
+#pod         . = use autodie ':all';
 #pod
 #pod specifies code, which will be executed as initial part of all other hooks. Again: C<Hook> itself
 #pod does not execute its code, if there is no other hooks in F<dist.ini>, this code will never execute.
@@ -63,7 +62,7 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Write C<Dist::Zilla> plugin directly in F<dist.ini>
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
@@ -101,29 +100,28 @@ Dist::Zilla::Plugin::Hook - Write C<Dist::Zilla> plugin directly in F<dist.ini>
 
 =head1 VERSION
 
-Version 0.005, released on 2015-08-07 22:29 UTC.
+Version 0.006, released on 2015-08-11 20:12 UTC.
 
 =head1 WHAT?
 
 C<Dist-Zilla-Plugin-Hook> (or just C<Hook>) is a set of C<Dist-Zilla> plugins. Every plugin executes Perl
 code inlined into F<dist.ini> at particular stage of build process.
 
-This is C<Dist::Zilla::Plugin::Hook> module documentation. Read this if you are going to hack
-or extend C<Dist-Zilla-Plugin-Hook>.
+This is C<Dist::Zilla::Plugin::Hook> module documentation. Read this if you are going to hack or
+extend C<Dist-Zilla-Plugin-Hook>.
 
-If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>.
-General topics like getting source, building, installing, bug reporting and some others are covered
-in the L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
+If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
+topics like getting source, building, installing, bug reporting and some others are covered in the
+L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
 
 =head1 DESCRIPTION
 
 This plugin consumes C<Hooker> role like all other C<Hook> plugins. However, this plugin I<never>
-executes its Perl code. Instead, it just stores it for later use by other plugins.
-
-For example, F<dist.ini> section
+executes its Perl code. Instead, it just stores it for later use by other plugins. As of today,
+only C<Hook> plugin with C<prologue> name is actually used:
 
     [Hook/prologue]
-        . = use autodiue ':all';
+        . = use autodie ':all';
 
 specifies code, which will be executed as initial part of all other hooks. Again: C<Hook> itself
 does not execute its code, if there is no other hooks in F<dist.ini>, this code will never execute.
